Name:       pure-ftpd
Version:    1.0.51
Release:    2%{?dist}
Summary:    Lightweight, fast and secure FTP server
License:    BSD
URL:        http://www.pureftpd.org

Source0:    http://download.pureftpd.org/pub/pure-ftpd/releases/pure-ftpd-%{version}.tar.bz2
Source1:    pure-ftpd.service
Source2:    pure-ftpd.logrotate
Source6:    pure-ftpd.README.SELinux
Source7:    pure-ftpd.pureftpd.te
Source8:    pure-ftpd-with-tls-init.service
Source9:    pure-ftpd-with-tls.service
Patch0:     0001-modify-pam.patch
Patch1:     0002-specific-config-file.patch

Provides:   ftpserver
BuildRequires: make
BuildRequires:  pam-devel, libcap-devel
%{!?_without_ldap:BuildRequires:  openldap-devel}
%{!?_without_mysql:BuildRequires: mariadb-connector-c-devel}
%{!?_without_pgsql:BuildRequires: libpq-devel}
%{!?_without_tls:BuildRequires: openssl-devel}
BuildRequires: checkpolicy, selinux-policy-devel
BuildRequires: systemd
BuildRequires: git
BuildRequires: gcc
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires:   logrotate
%{!?_without_tls:Requires: sscg}


%description
Pure-FTPd is a fast, production-quality, standard-comformant FTP server,
based upon Troll-FTPd. Unlike other popular FTP servers, it has no known
security flaw, it is really trivial to set up and it is especially designed
for modern Linux and FreeBSD kernels (setfsuid, sendfile, capabilities) .
Features include PAM support, IPv6, chroot()ed home directories, virtual
domains, built-in LS, anti-warez system, bandwidth throttling, FXP, bounded
ports for passive downloads, UL/DL ratios, native LDAP and SQL support,
Apache log files and more.
Rebuild switches:
--without ldap     disable ldap support
--without mysql    disable mysql support
--without pgsql    disable postgresql support
--without extauth  disable external authentication
--without tls      disable SSL/TLS


%package    selinux
Summary:    SELinux support for Pure-FTPD
Requires:   %{name} = %{version}
Requires(post): policycoreutils, %{name}
Requires(preun): policycoreutils, %{name}
Requires(postun): policycoreutils

%description selinux
This package adds SELinux enforcement to Pure-FTPD. Install it if you want
Pure-FTPd to be protected in the same way other FTP servers are in Fedora
(e.g. VSFTPd and ProFTPd)



%prep
%autosetup -S git
install -pm 644 %{SOURCE6} README.SELinux
mkdir selinux
cp -p %{SOURCE7} selinux/pureftpd.te


%build
%configure  \
            --sysconfdir=%{_sysconfdir}/%{name} \
            --with-capabilities \
            --with-sendfile \
            --with-paranoidmsg \
            --with-altlog \
            --with-puredb \
            %{!?_without_extauth:--with-extauth} \
            --with-pam \
            --with-cookie \
            --with-throttling \
            --with-ratios \
            --with-quotas \
            --with-ftpwho \
            --with-welcomemsg \
            --with-uploadscript \
            --with-virtualhosts \
            --with-virtualchroot \
            --with-diraliases \
            --with-peruserlimits \
            %{!?_without_ldap:--with-ldap} \
            %{!?_without_mysql:--with-mysql} \
            %{!?_without_pgsql:--with-pgsql} \
            --with-privsep \
            %{!?_without_tls:--with-tls --with-certfile=%{_sysconfdir}/pki/%{name}/%{name}.pem} \
            --with-rfc2640 \
            --without-bonjour \

%make_build

%install
%make_install

install -d -m 755 %{buildroot}%{_mandir}/man8
install -d -m 755 %{buildroot}%{_sbindir}
install -d -m 755 %{buildroot}%{_unitdir}
install -d -m 755 %{buildroot}%{_sysconfdir}/%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/ftp
%{!?_without_tls:install -d -m 700 %{buildroot}%{_sysconfdir}/pki/%{name}}

install -p -m 644 pure-ftpd.conf %{buildroot}%{_sysconfdir}/%{name}
install -p -m 644 pureftpd-ldap.conf %{buildroot}%{_sysconfdir}/%{name}
install -p -m 644 pureftpd-mysql.conf %{buildroot}%{_sysconfdir}/%{name}
install -p -m 644 pureftpd-pgsql.conf %{buildroot}%{_sysconfdir}/%{name}

install -p -m 644 man/pure-ftpd.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-ftpwho.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-mrtginfo.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-uploadscript.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-pw.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-pwconvert.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-statsdecode.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-quotacheck.8 %{buildroot}%{_mandir}/man8
install -p -m 644 man/pure-authd.8 %{buildroot}%{_mandir}/man8

%if 0%{!?_without_tls:1}
install -p -m 644 %{SOURCE8} %{buildroot}%{_unitdir}/pure-ftpd-init.service
install -p -m 644 %{SOURCE9} %{buildroot}%{_unitdir}/pure-ftpd.service
%else
install -p -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/pure-ftpd.service
%endif

install -d -m 755 %{buildroot}%{_sysconfdir}/pam.d
install -p -m 644 pam/pure-ftpd %{buildroot}%{_sysconfdir}/pam.d/

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

pushd selinux
echo "%{_sbindir}/pure-ftpd    system_u:object_r:ftpd_exec_t:s0" > pureftpd.fc
echo '%{_localstatedir}/log/pureftpd.log    system_u:object_r:xferlog_t:s0' >> pureftpd.fc
touch pureftpd.if
make -f %{_datadir}/selinux/devel/Makefile
install -p -m 644 -D pureftpd.pp %{buildroot}%{_datadir}/selinux/packages/%{name}/pureftpd.pp
popd

rm %{buildroot}%{_docdir}/%{name}/README.MacOS-X

%post
%systemd_post pure-ftpd.service

%preun
%systemd_preun pure-ftpd.service

%postun
%systemd_postun_with_restart pure-ftpd.service


%post selinux
if [ "$1" -le "1" ]; then # Fist install
    semodule -i %{_datadir}/selinux/packages/%{name}/pureftpd.pp 2>/dev/null || :
    fixfiles -R pure-ftpd restore || :
    /bin/systemctl condrestart pure-ftpd > /dev/null 2>&1  || :
fi

%preun selinux
if [ "$1" -lt "1" ]; then # Final removal
    semodule -r pureftpd 2>/dev/null || :
    fixfiles -R pure-ftpd restore || :
    /bin/systemctl condrestart pure-ftpd > /dev/null 2>&1  || :
fi

%postun selinux
if [ "$1" -ge "1" ]; then # Upgrade
    semodule -i %{_datadir}/selinux/packages/%{name}/pureftpd.pp 2>/dev/null || :
fi


%files
%doc FAQ THANKS AUTHORS HISTORY NEWS
%doc README README.Authentication-Modules README.Configuration-File
%doc README.Donations README.LDAP README.MySQL README.SELinux
%doc README.PGSQL README.TLS README.Virtual-Users
%doc pureftpd.schema
%doc %{_docdir}/%{name}/*.conf
%{_bindir}/pure-*
%{_sbindir}/pure-*
%if 0%{!?_without_tls:1}
%{_unitdir}/pure-ftpd-init.service
%{_unitdir}/pure-ftpd.service
%else
%{_unitdir}/pure-ftpd.service
%endif
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{!?_without_tls:%{_sysconfdir}/pki/%{name}}
%{_mandir}/man8/*
%dir /var/ftp/


%files selinux
%doc README.SELinux
%{_datadir}/selinux/packages/%{name}/pureftpd.pp


%changelog
* Tue May 07 2024 Fanjun Kong <fanjunkong@tencent.com> - 1.0.51-2
- epol debrand

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.0.51-1
- initial build
